#
# spec file for package python-flake8-builtins
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-flake8-builtins
Version:        2.5.0
Release:        1.3
Summary:        Flake8 Builtins plugin
License:        GPL-2.0-only
URL:            https://github.com/gforcada/flake8-builtins
Source:         https://files.pythonhosted.org/packages/source/f/flake8-builtins/flake8_builtins-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.7}
BuildRequires:  %{python_module hatchling}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-flake8 >= 5.0.4
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module flake8 >= 5.0.4}
BuildRequires:  %{python_module hypothesis}
BuildRequires:  %{python_module hypothesmith}
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
This plugin checks for Python builtins being used as variables or parameters.

%prep
%setup -q -n flake8_builtins-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# test_builtin_works_on_many_examples - will crash in obs as it is speed related
%pytest run_tests.py -k 'not test_builtin_works_on_many_examples'

%files %{python_files}
%license LICENSE
%doc CHANGES.rst README.rst
%{python_sitelib}/flake8_builtins.py
%pycache_only %{python_sitelib}/__pycache__/flake8_builtins*
%{python_sitelib}/flake8_builtins-%{version}.dist-info

%changelog
* Sat Apr 20 2024 Dirk Müller <dmueller@suse.com>
- update to 2.5.0:
  * Support detecting a shadowing folder as module name (as part
    of A005). [asfaltboy]
  * Add rule for lambda argument shadowing (A006). [cielavenir]
  * Add rule for builtin module name shadowing (A005).
    [asfaltboy]
* Wed Dec 27 2023 Dirk Müller <dmueller@suse.com>
- update to 2.2.0:
  * Drop python 3.7 support.
  * Test pre-release of python 3.12.
  * Use `pyproject.toml` rather than `setup.py`.
  * Switch from `setuptools` to `hatchling`.
  * Add rule for import shadowing (`A004`).
  * Switch to `main` branch.
* Mon Jan  2 2023 Dirk Müller <dmueller@suse.com>
- update to 2.1.0:
  * Honor `--builtins` option from flake8
* Thu Dec 15 2022 Dirk Müller <dmueller@suse.com>
- update to 2.0.1:
  * Add official support for python 3.10 and 3.11. [gforcada] [michael-k]
  * Update options handling. [gforcada]
  * Mark support for python 3.9. [lovetoburnswhen]
  * Drop python 2.7 and 3.6. [gforcada]
  * Overhaul GitHub actions to test on actual supported python versions.
  * New flake8 option `--builtins-ignorelist` to specify a list of builtins
    to ignore. [gsingh93]
* Thu Sep 17 2020 Dirk Mueller <dmueller@suse.com>
- update to 1.5.3:
  - Change messages to have shorter text
* Thu Apr 16 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.5.2:
  * Add python3.8 support. [sobolevn]
  * Add AnnAssign support. [soboelvn]
  * Add NamedExpr or := support. [sobolevn]
  * Adds kwonly and posonly args support. [sobolevn]
  * Add DictComp, SetComp, and GeneratorExpr support. [sobolevn]
* Sat Aug 24 2019 Jan Engelhardt <jengelh@inai.de>
- Use proper full sentences in descriptions.
* Mon Jul 15 2019 Andreas Färber <afaerber@suse.de>
- Initial (v1.4.1)
